@@ -1,4 +1,4 @@
-/* $OpenBSD: s_cb.c,v 1.9 2018/01/15 11:02:07 inoguchi Exp $ */
+/* $OpenBSD: s_cb.c,v 1.10 2018/04/25 07:12:33 tb Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -821,7 +821,8 @@ generate_cookie_callback(SSL * ssl, unsigned char *cookie,
 }
 
 int
-verify_cookie_callback(SSL * ssl, unsigned char *cookie, unsigned int cookie_len)
+verify_cookie_callback(SSL * ssl, const unsigned char *cookie,
+    unsigned int cookie_len)
 {
 	unsigned char *buffer, result[EVP_MAX_MD_SIZE];
 	unsigned int length, resultlength;
