@@ -1,4 +1,4 @@
-/* $OpenBSD: d1_srvr.c,v 1.91 2017/10/12 15:52:50 jsing Exp $ */
+/* $OpenBSD: d1_srvr.c,v 1.92 2018/04/07 17:02:34 jsing Exp $ */
 /*
  * DTLS implementation written by Nagendra Modadugu
  * (nagendra@cs.stanford.edu) for the OpenSSL project 2005.
@@ -134,9 +134,6 @@ static const SSL_METHOD_INTERNAL DTLSv1_server_method_internal_data = {
 	.ssl_free = dtls1_free,
 	.ssl_accept = ssl3_accept,
 	.ssl_connect = ssl_undefined_function,
-	.ssl_read = ssl3_read,
-	.ssl_peek = ssl3_peek,
-	.ssl_write = ssl3_write,
 	.ssl_shutdown = dtls1_shutdown,
 	.ssl_pending = ssl3_pending,
 	.get_ssl_method = dtls1_get_server_method,
