@@ -1,4 +1,4 @@
-/* $OpenBSD: t1_meth.c,v 1.23 2017/01/26 05:31:25 jsing Exp $ */
+/* $OpenBSD: t1_meth.c,v 1.24 2018/04/07 17:02:34 jsing Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -73,9 +73,6 @@ static const SSL_METHOD_INTERNAL TLS_method_internal_data = {
 	.ssl_free = tls1_free,
 	.ssl_accept = ssl3_accept,
 	.ssl_connect = ssl3_connect,
-	.ssl_read = ssl3_read,
-	.ssl_peek = ssl3_peek,
-	.ssl_write = ssl3_write,
 	.ssl_shutdown = ssl3_shutdown,
 	.ssl_pending = ssl3_pending,
 	.get_ssl_method = tls1_get_method,
@@ -107,9 +104,6 @@ static const SSL_METHOD_INTERNAL TLSv1_method_internal_data = {
 	.ssl_free = tls1_free,
 	.ssl_accept = ssl3_accept,
 	.ssl_connect = ssl3_connect,
-	.ssl_read = ssl3_read,
-	.ssl_peek = ssl3_peek,
-	.ssl_write = ssl3_write,
 	.ssl_shutdown = ssl3_shutdown,
 	.ssl_pending = ssl3_pending,
 	.get_ssl_method = tls1_get_method,
@@ -141,9 +135,6 @@ static const SSL_METHOD_INTERNAL TLSv1_1_method_internal_data = {
 	.ssl_free = tls1_free,
 	.ssl_accept = ssl3_accept,
 	.ssl_connect = ssl3_connect,
-	.ssl_read = ssl3_read,
-	.ssl_peek = ssl3_peek,
-	.ssl_write = ssl3_write,
 	.ssl_shutdown = ssl3_shutdown,
 	.ssl_pending = ssl3_pending,
 	.get_ssl_method = tls1_get_method,
@@ -175,9 +166,6 @@ static const SSL_METHOD_INTERNAL TLSv1_2_method_internal_data = {
 	.ssl_free = tls1_free,
 	.ssl_accept = ssl3_accept,
 	.ssl_connect = ssl3_connect,
-	.ssl_read = ssl3_read,
-	.ssl_peek = ssl3_peek,
-	.ssl_write = ssl3_write,
 	.ssl_shutdown = ssl3_shutdown,
 	.ssl_pending = ssl3_pending,
 	.get_ssl_method = tls1_get_method,
